@@ -11,13 +11,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import os
-from time import sleep
 from typing import Optional
 
-from testcontainers.core.config import MAX_TRIES, SLEEP_TIME
 from testcontainers.core.generic import DbContainer
 from testcontainers.core.utils import raise_for_deprecated_parameter
-from testcontainers.core.waiting_utils import wait_container_is_ready, wait_for_logs
+from testcontainers.core.waiting_utils import wait_container_is_ready
 
 _UNSET = object()
 
@@ -79,7 +77,7 @@ class PostgresContainer(DbContainer):
         driver. The optional driver argument to :code:`get_connection_url` overwrites the constructor
         set value. Pass :code:`driver=None` to get URLs without a driver.
         """
-        driver_str = self.driver if driver is _UNSET else f"+{driver}"
+        driver_str = "" if driver is None else self.driver if driver is _UNSET else f"+{driver}"
         return super()._create_connection_url(
             dialect=f"postgresql{driver_str}",
             username=self.username,
@@ -91,15 +89,13 @@ class PostgresContainer(DbContainer):
 
     @wait_container_is_ready()
     def _connect(self) -> None:
-        wait_for_logs(self, ".*database system is ready to accept connections.*", MAX_TRIES, SLEEP_TIME)
-
-        count = 0
-        while count < MAX_TRIES:
-            status, _ = self.exec(f"pg_isready -hlocalhost -p{self.port} -U{self.username}")
-            if status == 0:
-                return
-
-            sleep(SLEEP_TIME)
-            count += 1
-
-        raise RuntimeError("Postgres could not get into a ready state")
+        escaped_single_password = self.password.replace("'", "'\"'\"'")
+        result = self.exec(
+            [
+                "sh",
+                "-c",
+                f"PGPASSWORD='{escaped_single_password}' psql --username {self.username} --dbname {self.dbname} --host 127.0.0.1 -c 'select version();'",
+            ]
+        )
+        if result.exit_code:
+            raise ConnectionError("pg_isready is not ready yet")
