@@ -1,4 +1,3 @@
-from testcontainers.core.config import MAX_TRIES
 from testcontainers.core.generic import DockerContainer
 from testcontainers.core.waiting_utils import wait_container_is_ready, wait_for_logs
 
@@ -27,9 +26,9 @@ class ScyllaContainer(DockerContainer):
         self.with_exposed_ports(*self.ports_to_expose)
         self.with_command("--skip-wait-for-gossip-to-settle=0")
 
-    @wait_container_is_ready()
+    @wait_container_is_ready(OSError)
     def _connect(self):
-        wait_for_logs(self, predicate="Starting listening for CQL clients", timeout=MAX_TRIES)
+        wait_for_logs(self, predicate="Starting listening for CQL clients")
         cluster = self.get_cluster()
         cluster.connect()
 
@@ -41,7 +40,6 @@ class ScyllaContainer(DockerContainer):
     def get_cluster(self, **kwargs):
         from cassandra.cluster import Cluster
 
-        container = self.get_wrapped_container()
-        container.reload()
-        hostname = container.attrs["NetworkSettings"]["IPAddress"]
-        return Cluster(contact_points=[hostname], **kwargs)
+        hostname = self.get_container_host_ip()
+        port = self.get_exposed_port(9042)
+        return Cluster(contact_points=[hostname], port=port, **kwargs)
